==> zio-aws-rds_2.12-5.17.112.1-sources.jar: zio/aws/rds/model/CreateOptionGroupResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateOptionGroupResponse(
    optionGroup: scala.Option[zio.aws.rds.model.OptionGroup] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse = {
    import CreateOptionGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
      .builder()
      .optionallyWith(optionGroup.map(value => value.buildAwsValue()))(
        _.optionGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.CreateOptionGroupResponse.ReadOnly =
    zio.aws.rds.model.CreateOptionGroupResponse.wrap(buildAwsValue())
}
object CreateOptionGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CreateOptionGroupResponse =
      zio.aws.rds.model
        .CreateOptionGroupResponse(optionGroup.map(value => value.asEditable))
    def optionGroup: scala.Option[zio.aws.rds.model.OptionGroup.ReadOnly]
    def getOptionGroup
        : ZIO[Any, AwsError, zio.aws.rds.model.OptionGroup.ReadOnly] =
      AwsError.unwrapOptionField("optionGroup", optionGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
  ) extends zio.aws.rds.model.CreateOptionGroupResponse.ReadOnly {
    override val optionGroup
        : scala.Option[zio.aws.rds.model.OptionGroup.ReadOnly] = scala
      .Option(impl.optionGroup())
      .map(value => zio.aws.rds.model.OptionGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
  ): zio.aws.rds.model.CreateOptionGroupResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_2.13-5.19.33.1-sources.jar: zio/aws/rds/model/CreateOptionGroupResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateOptionGroupResponse(
    optionGroup: Optional[zio.aws.rds.model.OptionGroup] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse = {
    import CreateOptionGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
      .builder()
      .optionallyWith(optionGroup.map(value => value.buildAwsValue()))(
        _.optionGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.CreateOptionGroupResponse.ReadOnly =
    zio.aws.rds.model.CreateOptionGroupResponse.wrap(buildAwsValue())
}
object CreateOptionGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CreateOptionGroupResponse =
      zio.aws.rds.model
        .CreateOptionGroupResponse(optionGroup.map(value => value.asEditable))
    def optionGroup: Optional[zio.aws.rds.model.OptionGroup.ReadOnly]
    def getOptionGroup
        : ZIO[Any, AwsError, zio.aws.rds.model.OptionGroup.ReadOnly] =
      AwsError.unwrapOptionField("optionGroup", optionGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
  ) extends zio.aws.rds.model.CreateOptionGroupResponse.ReadOnly {
    override val optionGroup: Optional[zio.aws.rds.model.OptionGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.optionGroup())
        .map(value => zio.aws.rds.model.OptionGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CreateOptionGroupResponse
  ): zio.aws.rds.model.CreateOptionGroupResponse.ReadOnly = new Wrapper(impl)
}
